@@ -93,6 +93,7 @@ static void cb_show_save_dialog_toggled (GtkToggleButton *tb,
 static void cb_default_folder (GtkWidget       *chooser, 
                                ScreenshotData  *sd)
 {
+  g_free (sd->screenshot_dir);
   sd->screenshot_dir = 
     gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
 }
@@ -121,6 +122,7 @@ static void cb_combo_active_item_changed (GtkWidget *box, ScreenshotData *sd)
   
   gtk_tree_model_get (model, &iter, 2, &active_command, -1);
   
+  g_free (sd->app);
   sd->app = active_command;
 }
 
@@ -134,6 +136,7 @@ static void add_item (GAppInfo *app_info, GtkWidget *liststore)
   gchar *name = g_strdup (g_app_info_get_name (app_info));
   GIcon *icon = g_app_info_get_icon (app_info);
   GdkPixbuf *pixbuf = NULL;
+  GtkIconTheme *icon_theme = gtk_icon_theme_get_default ();
   
   /* Get the icon */
   if (G_IS_LOADABLE_ICON (icon))
@@ -155,8 +158,6 @@ static void add_item (GAppInfo *app_info, GtkWidget *liststore)
            
       if (names != NULL)
         {
-          GtkIconTheme *icon_theme = gtk_icon_theme_get_default ();
-          
           if (names[0] != NULL)
             {
               pixbuf = 
@@ -171,6 +172,13 @@ static void add_item (GAppInfo *app_info, GtkWidget *liststore)
         }
     }
   
+  if (pixbuf == NULL)
+    {
+      pixbuf = gtk_icon_theme_load_icon (icon_theme, "exec", ICON_SIZE,
+                                         GTK_ICON_LOOKUP_GENERIC_FALLBACK,
+                                         NULL);
+    }
+  
   /* Add to the liststore */
   gtk_list_store_append (GTK_LIST_STORE (liststore), &iter);
           
